@@ -1,11 +1,8 @@
 use strict;
 use warnings;
 package Email::Simple::Creator;
-{
-  $Email::Simple::Creator::VERSION = '2.202';
-}
 # ABSTRACT: private helper for building Email::Simple objects
-
+$Email::Simple::Creator::VERSION = '2.204';
 sub _crlf {
   "\x0d\x0a";
 }
@@ -15,9 +12,16 @@ sub _date_header {
   Email::Date::Format::email_date();
 }
 
+our @CARP_NOT = qw(Email::Simple Email::MIME);
+
 sub _add_to_header {
   my ($class, $header, $key, $value) = @_;
   $value = '' unless defined $value;
+
+  if ($value =~ s/[\x0a\x0b\x0c\x0d\x85\x{2028}\x{2029}]+/ /g) {
+    Carp::carp("replaced vertical whitespace in $key header with space; this will become fatal in a future version");
+  }
+
   $$header .= "$key: $value" . $class->_crlf;
 }
 
@@ -32,13 +36,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Email::Simple::Creator - private helper for building Email::Simple objects
 
 =head1 VERSION
 
-version 2.202
+version 2.204
 
 =head1 AUTHORS
 
