@@ -2,35 +2,35 @@ use strict;
 use warnings;
 package Email::Simple::Header;
 # ABSTRACT: the header of an Email::Simple message
-$Email::Simple::Header::VERSION = '2.203';
+$Email::Simple::Header::VERSION = '2.204';
 use Carp ();
 
 require Email::Simple;
 
-# =head1 SYNOPSIS
-#
-#   my $email = Email::Simple->new($text);
-#
-#   my $header = $email->header_obj;
-#   print $header->as_string;
-#
-# =head1 DESCRIPTION
-#
-# This method implements the headers of an Email::Simple object.  It is a very
-# minimal interface, and is mostly for private consumption at the moment.
-#
-# =method new
-#
-#   my $header = Email::Simple::Header->new($head, \%arg);
-#
-# C<$head> is a string containing a valid email header, or a reference to such a
-# string.  If a reference is passed in, don't expect that it won't be altered.
-#
-# Valid arguments are:
-#
-#   crlf - the header's newline; defaults to CRLF
-#
-# =cut
+#pod =head1 SYNOPSIS
+#pod
+#pod   my $email = Email::Simple->new($text);
+#pod
+#pod   my $header = $email->header_obj;
+#pod   print $header->as_string;
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod This method implements the headers of an Email::Simple object.  It is a very
+#pod minimal interface, and is mostly for private consumption at the moment.
+#pod
+#pod =method new
+#pod
+#pod   my $header = Email::Simple::Header->new($head, \%arg);
+#pod
+#pod C<$head> is a string containing a valid email header, or a reference to such a
+#pod string.  If a reference is passed in, don't expect that it won't be altered.
+#pod
+#pod Valid arguments are:
+#pod
+#pod   crlf - the header's newline; defaults to CRLF
+#pod
+#pod =cut
 
 # We need to be able to:
 #   * get all values by lc name
@@ -82,13 +82,13 @@ sub _header_to_list {
   return \@headers;
 }
 
-# =method as_string
-#
-#   my $string = $header->as_string(\%arg);
-#
-# This returns a stringified version of the header.
-#
-# =cut
+#pod =method as_string
+#pod
+#pod   my $string = $header->as_string(\%arg);
+#pod
+#pod This returns a stringified version of the header.
+#pod
+#pod =cut
 
 # RFC 2822, 3.6:
 # ...for the purposes of this standard, header fields SHOULD NOT be reordered
@@ -124,12 +124,12 @@ sub as_string {
   return $header_str;
 }
 
-# =method header_names
-#
-# This method returns a list of the unique header names found in this header, in
-# no particular order.
-#
-# =cut
+#pod =method header_names
+#pod
+#pod This method returns a list of the unique header names found in this header, in
+#pod no particular order.
+#pod
+#pod =cut
 
 sub header_names {
   my $headers = $_[0]->{headers};
@@ -139,19 +139,27 @@ sub header_names {
     map { $headers->[ $_ * 2 ] } 0 .. int($#$headers / 2);
 }
 
-# =method header_pairs
-#
-#   my @pairs = $header->header_pairs;
-#   my $first_name  = $pairs[0];
-#   my $first_value = $pairs[1];
-#
-# This method returns a list of all the field/value pairs in the header, in the
-# order that they appear in the header.  (Remember: don't try assigning that to a
-# hash.  Some fields may appear more than once!)
-#
-# =cut
+#pod =method header_raw_pairs
+#pod
+#pod   my @pairs = $header->header_raw_pairs;
+#pod   my $first_name  = $pairs[0];
+#pod   my $first_value = $pairs[1];
+#pod
+#pod This method returns a list of all the field/value pairs in the header, in the
+#pod order that they appear in the header.  (Remember: don't try assigning that to a
+#pod hash.  Some fields may appear more than once!)
+#pod
+#pod =method header_pairs
+#pod
+#pod L<header_pairs> is another name for L<header_raw_pairs>, which was the original
+#pod name for the method and which you'll see most often.  In general, though, it's
+#pod better to be explicit and use L<header_raw_pairs>.  (In Email::MIME,
+#pod L<header_str_pairs> exists for letting the library do the header decoding for
+#pod you.)
+#pod
+#pod =cut
 
-sub header_pairs {
+sub header_raw_pairs {
   my ($self) = @_;
 
   my @pairs = map {; _str_value($_) } @{ $self->{headers} };
@@ -159,19 +167,30 @@ sub header_pairs {
   return @pairs;
 }
 
-# =method header
-#
-#   my $first_value = $header->header($field);
-#   my @all_values  = $header->header($field);
-#
-# This method returns the value or values of the given header field.  If the
-# named field does not appear in the header, this method returns false.
-#
-# =cut
+sub header_pairs {
+  my ($self) = @_;
+  $self->header_raw_pairs;
+}
+
+#pod =method header_raw
+#pod
+#pod   my $first_value = $header->header_raw($field);
+#pod   my @all_values  = $header->header_raw($field);
+#pod
+#pod This method returns the value or values of the given header field.  If the
+#pod named field does not appear in the header, this method returns false.
+#pod
+#pod =method header
+#pod
+#pod This method just calls C<header_raw>.  It's the older name for C<header_raw>,
+#pod but it can be a problem because L<Email::MIME>, a subclass of Email::Simple,
+#pod makes C<header> return the header's decoded value.
+#pod
+#pod =cut
 
 sub _str_value { return ref $_[0] ? $_[0][0] : $_[0] }
 
-sub header {
+sub header_raw {
   my ($self, $field) = @_;
 
   my $headers  = $self->{headers};
@@ -188,15 +207,28 @@ sub header {
   }
 }
 
-# =method header_set
-#
-#   $header->header_set($field => @values);
-#
-# This method updates the value of the given header.  Existing headers have their
-# values set in place.  Additional headers are added at the end.  If no values
-# are given to set, the header will be removed from to the message entirely.
-#
-# =cut
+sub header {
+  my ($self, $field) = @_;
+  $self->header_raw($field);
+}
+
+#pod =method header_raw_set
+#pod
+#pod   $header->header_raw_set($field => @values);
+#pod
+#pod This method updates the value of the given header.  Existing headers have their
+#pod values set in place.  Additional headers are added at the end.  If no values
+#pod are given to set, the header will be removed from to the message entirely.
+#pod
+#pod =method header_set
+#pod
+#pod L<header_set> is another name for L<header_raw_set>, which was the original
+#pod name for the method and which you'll see most often.  In general, though, it's
+#pod better to be explicit and use L<header_raw_set>.  (In Email::MIME,
+#pod L<header_str_set> exists for letting the library do the header encoding for
+#pod you.)
+#pod
+#pod =cut
 
 # Header fields are lines composed of a field name, followed by a colon (":"),
 # followed by a field body, and terminated by CRLF.  A field name MUST be
@@ -207,7 +239,7 @@ sub header {
 # However, a field body may contain CRLF when used in header "folding" and
 # "unfolding" as described in section 2.2.3.
 
-sub header_set {
+sub header_raw_set {
   my ($self, $field, @data) = @_;
 
   # I hate this block. -- rjbs, 2006-10-06
@@ -243,11 +275,16 @@ sub header_set {
   return wantarray ? @data : $data[0];
 }
 
-# =method crlf
-#
-# This method returns the newline string used in the header.
-#
-# =cut
+sub header_set {
+  my ($self, $field, @data) = @_;
+  $self->header_raw_set($field, @data);
+}
+
+#pod =method crlf
+#pod
+#pod This method returns the newline string used in the header.
+#pod
+#pod =cut
 
 sub crlf { $_[0]->{mycrlf} }
 
@@ -330,7 +367,7 @@ Email::Simple::Header - the header of an Email::Simple message
 
 =head1 VERSION
 
-version 2.203
+version 2.204
 
 =head1 SYNOPSIS
 
@@ -368,9 +405,9 @@ This returns a stringified version of the header.
 This method returns a list of the unique header names found in this header, in
 no particular order.
 
-=head2 header_pairs
+=head2 header_raw_pairs
 
-  my @pairs = $header->header_pairs;
+  my @pairs = $header->header_raw_pairs;
   my $first_name  = $pairs[0];
   my $first_value = $pairs[1];
 
@@ -378,22 +415,44 @@ This method returns a list of all the field/value pairs in the header, in the
 order that they appear in the header.  (Remember: don't try assigning that to a
 hash.  Some fields may appear more than once!)
 
-=head2 header
+=head2 header_pairs
 
-  my $first_value = $header->header($field);
-  my @all_values  = $header->header($field);
+L<header_pairs> is another name for L<header_raw_pairs>, which was the original
+name for the method and which you'll see most often.  In general, though, it's
+better to be explicit and use L<header_raw_pairs>.  (In Email::MIME,
+L<header_str_pairs> exists for letting the library do the header decoding for
+you.)
+
+=head2 header_raw
+
+  my $first_value = $header->header_raw($field);
+  my @all_values  = $header->header_raw($field);
 
 This method returns the value or values of the given header field.  If the
 named field does not appear in the header, this method returns false.
 
-=head2 header_set
+=head2 header
 
-  $header->header_set($field => @values);
+This method just calls C<header_raw>.  It's the older name for C<header_raw>,
+but it can be a problem because L<Email::MIME>, a subclass of Email::Simple,
+makes C<header> return the header's decoded value.
+
+=head2 header_raw_set
+
+  $header->header_raw_set($field => @values);
 
 This method updates the value of the given header.  Existing headers have their
 values set in place.  Additional headers are added at the end.  If no values
 are given to set, the header will be removed from to the message entirely.
 
+=head2 header_set
+
+L<header_set> is another name for L<header_raw_set>, which was the original
+name for the method and which you'll see most often.  In general, though, it's
+better to be explicit and use L<header_raw_set>.  (In Email::MIME,
+L<header_str_set> exists for letting the library do the header encoding for
+you.)
+
 =head2 crlf
 
 This method returns the newline string used in the header.
